# atomate2-turbomole

Atomate2-turbomole is an add-on package for [atomate2](https://github.com/materialsproject/atomate2).

Atomate2-turbomole is built to work with Turbomole, and is built on top of open source
libraries such as [pymatgen](https://github.com/materialsproject/pymatgen),
[custodian](https://github.com/materialsproject/custodian),
[jobflow](https://github.com/materialsproject/jobflow)
and [turbomoleio](https://github.com/Matgenix/turbomoleio).

## License

This add-on is released under the same license as atomate2, modified BSD, the full text of which can
be found in this repository.
